@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -8,60 +8,60 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0015,
+        errors => 0.0035,
         participant => "Log::Any-null_adapter-1mil_log_trace",
-        rate => 1.3,
-        samples => 6,
-        time => 760,
+        rate => 1.6,
+        samples => 7,
+        time => 610,
         vs_slowest => 1,
       },
       {
-        errors => 0.0011,
+        errors => 0.00071,
+        participant => "Log::Any-null_adapter-1mil_is_trace",
+        rate => 2.5,
+        samples => 6,
+        time => 400,
+        vs_slowest => 1.5,
+      },
+      {
+        errors => 0.00041,
         participant => "Log::Any-no_adapter-1mil_is_trace",
         rate => 2.5,
         samples => 6,
         time => 400,
-        vs_slowest => 1.9,
+        vs_slowest => 1.5,
       },
       {
-        errors => 0.00048,
-        participant => "Log::Any-null_adapter-1mil_is_trace",
-        rate => 2.6,
-        samples => 6,
-        time => 390,
-        vs_slowest => 2,
-      },
-      {
-        errors => 0.00022,
+        errors => 0.00094,
         participant => "Log::Any-no_adapter-1mil_log_trace",
-        rate => 6.6,
-        samples => 6,
-        time => 150,
-        vs_slowest => 5,
+        rate => 6.4,
+        samples => 7,
+        time => 160,
+        vs_slowest => 3.9,
       },
       {
-        errors => 0.00014,
+        errors => 0.00013,
+        participant => "Log::ger-1mil_log_is_trace",
+        rate => 8.5,
+        samples => 6,
+        time => 120,
+        vs_slowest => 5.2,
+      },
+      {
+        errors => 0.00073,
         participant => "Log::ger-1mil_log_trace",
         rate => 9.9,
         samples => 6,
         time => 100,
-        vs_slowest => 7.5,
+        vs_slowest => 6,
       },
       {
-        errors => 0.00026,
-        participant => "Log::ger-1mil_log_is_trace",
-        rate => 11,
-        samples => 6,
-        time => 94,
-        vs_slowest => 8.1,
-      },
-      {
-        errors => 3.1e-05,
+        errors => 0.00012,
         participant => "Log::ger+Log::ger::OptAway-1mil_log_trace",
-        rate => 27.2,
-        samples => 7,
-        time => 36.8,
-        vs_slowest => 20.6,
+        rate => 25,
+        samples => 6,
+        time => 40,
+        vs_slowest => 15,
       },
     ],
     {
@@ -164,7 +164,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3209.347,
+                                              speed                        => 3270.621,
                                               stepping                     => 7,
                                             },
                                             {
@@ -259,7 +259,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3321.722,
+                                              speed                        => 3275.828,
                                               stepping                     => 7,
                                             },
                                             {
@@ -354,7 +354,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3256.574,
+                                              speed                        => "3251.730",
                                               stepping                     => 7,
                                             },
                                             {
@@ -449,18 +449,18 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3270.136,
+                                              speed                        => 3223.757,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 14.465735912323,
+      "func.elapsed_time"              => 14.1909680366516,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.036,
                                             "Bencher::Scenario::LogGer::NullOutput" => undef,
-                                            "Benchmark::Dumb" => "0.10",
+                                            "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
-                                            "perl" => "v5.24.0",
+                                            "perl" => "v5.26.0",
                                             "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
@@ -490,13 +490,13 @@ our $results = [
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NullOutput",
-      "func.scenario_module_md5sum"    => "765591a8d05df20726d2c31351d6ab41",
-      "func.scenario_module_mtime"     => 1497871491,
-      "func.scenario_module_sha1sum"   => "d03c10187e46de37ae91e0cf40b062de31890289",
-      "func.scenario_module_sha256sum" => "624b4f47f30ef1ccbc015a9020f128b32ad32c74cc3d8234ac6b187a94fca6a1",
-      "func.time_end"                  => 1497878320.5256,
+      "func.scenario_module_md5sum"    => "a0a45267597760c9370d0617368d1828",
+      "func.scenario_module_mtime"     => 1497916629,
+      "func.scenario_module_sha1sum"   => "46095d1d6ddebbe200aae9027586a1cc4a613a6b",
+      "func.scenario_module_sha256sum" => "e177306e2a66c65b2478f5b56b95b057b9d249e12a4688bde67c022eb5422a3f",
+      "func.time_end"                  => 1498040900.21778,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1497878306.05987,
+      "func.time_start"                => 1498040886.02681,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
@@ -513,7 +513,7 @@ our $results = [
 ];
 
 1;
-# ABSTRACT: Benchmark Log::Ger logging speed with the default/null output
+# ABSTRACT: Benchmark Log::ger logging speed with the default/null output
 
 =head1 DESCRIPTION
 
