@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Startup;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -8,76 +8,76 @@ our $results = [
     "OK",
     [
       {
-        errors      => 1.9e-05,
+        errors      => 5.9e-05,
         modver      => "",
         participant => "use Log::ger + use Log::ger::OptAway",
-        rate        => 76,
+        rate        => 66,
         samples     => 20,
-        time        => 13,
+        time        => 15,
         vs_slowest  => 1,
       },
       {
-        errors      => 1.8e-05,
+        errors      => 4.6e-05,
         modver      => "",
         participant => "use Log::Any + use Log::Any::Adapter::Screen",
-        rate        => 81,
+        rate        => 77,
         samples     => 20,
-        time        => 12,
-        vs_slowest  => 1.1,
+        time        => 13,
+        vs_slowest  => 1.2,
       },
       {
-        errors      => 3.2e-05,
+        errors      => 7.4e-05,
         modver      => 1.049,
         participant => "use Log::Any",
-        rate        => 98,
+        rate        => 91,
         samples     => 20,
-        time        => 10,
-        vs_slowest  => 1.3,
+        time        => 11,
+        vs_slowest  => 1.4,
       },
       {
-        errors      => 1.8e-05,
+        errors      => 2.2e-05,
         modver      => "",
         participant => "use Log::ger + use Log::ger::Output::Screen",
-        rate        => 190,
-        samples     => 21,
-        time        => 5.2,
-        vs_slowest  => 2.5,
-      },
-      {
-        errors      => 6e-05,
-        modver      => "",
-        participant => "use Log::ger ()",
-        rate        => 200,
+        rate        => 150,
         samples     => 20,
-        time        => 5,
-        vs_slowest  => 3,
+        time        => 6.8,
+        vs_slowest  => 2.2,
       },
       {
-        errors      => 2e-05,
-        modver      => "",
-        participant => "use Log::ger",
-        rate        => 220,
-        samples     => 20,
-        time        => 4.5,
-        vs_slowest  => 2.9,
-      },
-      {
-        errors      => 1.9e-05,
+        errors      => 1.1e-05,
         modver      => 0.15,
         participant => "use Log::Any",
-        rate        => 220,
-        samples     => 20,
-        time        => 4.5,
-        vs_slowest  => 2.9,
+        rate        => 210,
+        samples     => 21,
+        time        => 4.8,
+        vs_slowest  => 3.2,
       },
       {
-        errors      => 3.2e-05,
+        errors      => 2.7e-05,
+        modver      => "",
+        participant => "use Log::ger",
+        rate        => 340,
+        samples     => 20,
+        time        => 2.9,
+        vs_slowest  => 5.2,
+      },
+      {
+        errors      => 2.5e-05,
+        modver      => "",
+        participant => "use Log::ger ()",
+        rate        => 350,
+        samples     => 20,
+        time        => 2.8,
+        vs_slowest  => 5.4,
+      },
+      {
+        errors      => 1.7e-05,
         modver      => "",
         participant => "baseline",
-        rate        => 500,
+        rate        => 600,
         samples     => 20,
         time        => 2,
-        vs_slowest  => 7,
+        vs_slowest  => 9,
       },
     ],
     {
@@ -182,7 +182,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3389.656,
+                                              speed                        => "3226.300",
                                               stepping                     => 7,
                                             },
                                             {
@@ -277,7 +277,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3265.656,
+                                              speed                        => 3204.988,
                                               stepping                     => 7,
                                             },
                                             {
@@ -372,7 +372,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3299.925,
+                                              speed                        => 3257.906,
                                               stepping                     => 7,
                                             },
                                             {
@@ -467,7 +467,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3325.234,
+                                              speed                        => 3279.824,
                                               stepping                     => 7,
                                             },
                                           ],
@@ -475,14 +475,14 @@ our $results = [
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.036,
                                             "Bencher::Scenario::LogGer::Startup" => undef,
-                                            "Benchmark::Dumb" => "0.10",
+                                            "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
                                             "Log::Any" => 1.049,
                                             "Log::Any::Adapter::Screen" => 0.13,
-                                            "Log::ger" => 0.001,
-                                            "Log::ger::OptAway" => 0.001,
-                                            "Log::ger::Output::Screen" => 0.001,
-                                            "perl" => "v5.24.0",
+                                            "Log::ger" => 0.004,
+                                            "Log::ger::OptAway" => 0.002,
+                                            "Log::ger::Output::Screen" => 0.003,
+                                            "perl" => "v5.26.0",
                                             "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
@@ -490,7 +490,7 @@ our $results = [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [1.049, 0.15],
+                                            [0.15, 1.049],
                                             "participant",
                                             [0 .. 6],
                                           ],
@@ -519,12 +519,12 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Startup",
-      "func.scenario_module_md5sum"    => "22f637116ccd3afbc0f4b63819520b49",
-      "func.scenario_module_mtime"     => 1497871139,
-      "func.scenario_module_sha1sum"   => "d56fe4cdd672646daac0f7082a27e52fdaa2dbdf",
-      "func.scenario_module_sha256sum" => "3206382a19eba70a7b343b70cb17b43d21e8a76e0dc16ea8ffa08800c0e00350",
+      "func.scenario_module_md5sum"    => "a57eaf478b6a8ffc8ff3762aaa108159",
+      "func.scenario_module_mtime"     => 1498033235,
+      "func.scenario_module_sha1sum"   => "061bf666caa67799a00d1b078cf8106e05aa607d",
+      "func.scenario_module_sha256sum" => "21565efa6d7ddf008ea509fb2eafbbf91553f16488aba6b850c3b71d1bc4b8ba",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1497878320.72832,
+      "func.time_start"                => 1498040900.43217,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
